@@ -30,7 +30,7 @@ try:
     registration.register_json_schema_resource_type()
     registration.register_json_ld_resource_type()
     registration.register_indexing_policy_resource_type()
-    registration.register_workflow_policy_resource_type()
+    registration.workflow_policy_resource_type()
 
     urlpatterns.extend(chain(
         registration.JSON_SCHEMA_REGISTRATION_.urls,
